@@ -4,8 +4,6 @@
 
 import pytest
 
-from click.testing import CliRunner
-
 from octis.dataset.dataset import Dataset
 from octis.models.LDA import LDA
 from octis.models.LDA_tomopy import LDA_tomopy as LDATOMOTO
@@ -51,15 +49,18 @@ def test_model_output_lda(data_dir):
 
     # check topic-word-matrix format
     assert type(output['topic-word-matrix']) == np.ndarray
-    assert output['topic-word-matrix'].shape == (num_topics, len(dataset.get_vocabulary()))
+    assert output['topic-word-matrix'].shape == (num_topics, len(
+        dataset.get_vocabulary()))
 
     # check topic-document-matrix format
     assert type(output['topic-document-matrix']) == np.ndarray
-    assert output['topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[0]))
+    assert output['topic-document-matrix'].shape == (num_topics, len(
+        dataset.get_partitioned_corpus()[0]))
 
     # check test-topic-document-matrix format
     assert type(output['test-topic-document-matrix']) == np.ndarray
-    assert output['test-topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[2]))
+    assert output['test-topic-document-matrix'].shape == (num_topics, len(
+        dataset.get_partitioned_corpus()[2]))
 
 
 def test_model_output_etm(data_dir):
@@ -78,20 +79,26 @@ def test_model_output_etm(data_dir):
 
     # check topic-word-matrix format
     assert type(output['topic-word-matrix']) == np.ndarray
-    assert output['topic-word-matrix'].shape == (num_topics, len(dataset.get_vocabulary()))
+    assert output['topic-word-matrix'].shape == (num_topics, len(
+        dataset.get_vocabulary()))
 
     # check topic-document-matrix format
     assert type(output['topic-document-matrix']) == np.ndarray
-    assert output['topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[0]))
+    assert output['topic-document-matrix'].shape == (num_topics, len(
+        dataset.get_partitioned_corpus()[0]))
 
     # check test-topic-document-matrix format
     assert type(output['test-topic-document-matrix']) == np.ndarray
-    assert output['test-topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[2]))
+    assert output['test-topic-document-matrix'].shape == (num_topics, len(
+        dataset.get_partitioned_corpus()[2]))
 
-def test_model_output_etm_with_corpus_containing_single_word_document(data_dir):
+
+def test_model_output_etm_with_corpus_containing_single_word_document(
+        data_dir):
     texts_path = data_dir+"/sample_texts/unprepr_docs.txt"
-    p = Preprocessing(vocabulary=None, max_features=None, remove_punctuation=True,
-                       lemmatize=False, stopword_list='english')
+    p = Preprocessing(
+        vocabulary=None, max_features=None, remove_punctuation=True,
+        lemmatize=False, stopword_list='english')
     dataset = p.preprocess_dataset(
         documents_path=texts_path,
     )
@@ -108,15 +115,18 @@ def test_model_output_etm_with_corpus_containing_single_word_document(data_dir):
 
     # check topic-word-matrix format
     assert type(output['topic-word-matrix']) == np.ndarray
-    assert output['topic-word-matrix'].shape == (num_topics, len(dataset.get_vocabulary()))
+    assert output['topic-word-matrix'].shape == (num_topics, len(
+        dataset.get_vocabulary()))
 
     # check topic-document-matrix format
     assert type(output['topic-document-matrix']) == np.ndarray
-    assert output['topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[0]))
+    assert output['topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_partitioned_corpus()[0]))
 
     # check test-topic-document-matrix format
     assert type(output['test-topic-document-matrix']) == np.ndarray
-    assert output['test-topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[2]))
+    assert output['test-topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_partitioned_corpus()[2]))
 
 
 def test_model_output_etm_not_partitioned(data_dir):
@@ -135,19 +145,23 @@ def test_model_output_etm_not_partitioned(data_dir):
 
     # check topic-word-matrix format
     assert type(output['topic-word-matrix']) == np.ndarray
-    assert output['topic-word-matrix'].shape == (num_topics, len(dataset.get_vocabulary()))
+    assert output['topic-word-matrix'].shape == (
+        num_topics, len(dataset.get_vocabulary()))
 
     # check topic-document-matrix format
     assert type(output['topic-document-matrix']) == np.ndarray
-    assert output['topic-document-matrix'].shape == (num_topics, len(dataset.get_corpus()))
+    assert output['topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_corpus()))
 
 
-def test_model_output_etm_with_pickle_embeddings_file(data_dir, embeddings_dir):
+def test_model_output_etm_with_pickle_embeddings_file(
+        data_dir, embeddings_dir):
     dataset = Dataset()
     dataset.load_custom_dataset_from_folder(data_dir + '/M10')
     num_topics = 3
-    model = ETM(num_topics=num_topics, num_epochs=5, train_embeddings=False, 
-        embeddings_path=embeddings_dir +'/test_example/example.pickle')
+    model = ETM(
+        num_topics=num_topics, num_epochs=5, train_embeddings=False,
+        embeddings_path=embeddings_dir + '/test_example/example.pickle')
     output = model.train_model(dataset)
     assert 'topics' in output.keys()
     assert 'topic-word-matrix' in output.keys()
@@ -159,22 +173,29 @@ def test_model_output_etm_with_pickle_embeddings_file(data_dir, embeddings_dir):
 
     # check topic-word-matrix format
     assert type(output['topic-word-matrix']) == np.ndarray
-    assert output['topic-word-matrix'].shape == (num_topics, len(dataset.get_vocabulary()))
+    assert output['topic-word-matrix'].shape == (
+        num_topics, len(dataset.get_vocabulary()))
 
     # check topic-document-matrix format
     assert type(output['topic-document-matrix']) == np.ndarray
-    assert output['topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[0]))
+    assert output['topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_partitioned_corpus()[0]))
 
     # check test-topic-document-matrix format
     assert type(output['test-topic-document-matrix']) == np.ndarray
-    assert output['test-topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[2]))
+    assert output['test-topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_partitioned_corpus()[2]))
 
-def test_model_output_etm_with_binary_word2vec_embeddings_file(data_dir, embeddings_dir):
+
+def test_model_output_etm_with_binary_word2vec_embeddings_file(
+        data_dir, embeddings_dir):
     dataset = Dataset()
     dataset.load_custom_dataset_from_folder(data_dir + '/M10')
     num_topics = 3
-    model = ETM(num_topics=num_topics, num_epochs=5, train_embeddings=False, 
-        embeddings_type='word2vec', embeddings_path=embeddings_dir +'/test_example/example.bin')
+    model = ETM(
+        num_topics=num_topics, num_epochs=5, train_embeddings=False,
+        embeddings_type='word2vec',
+        embeddings_path=embeddings_dir + '/test_example/example.bin')
     output = model.train_model(dataset)
     assert 'topics' in output.keys()
     assert 'topic-word-matrix' in output.keys()
@@ -186,22 +207,28 @@ def test_model_output_etm_with_binary_word2vec_embeddings_file(data_dir, embeddi
 
     # check topic-word-matrix format
     assert type(output['topic-word-matrix']) == np.ndarray
-    assert output['topic-word-matrix'].shape == (num_topics, len(dataset.get_vocabulary()))
+    assert output['topic-word-matrix'].shape == (
+        num_topics, len(dataset.get_vocabulary()))
 
     # check topic-document-matrix format
     assert type(output['topic-document-matrix']) == np.ndarray
-    assert output['topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[0]))
+    assert output['topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_partitioned_corpus()[0]))
 
     # check test-topic-document-matrix format
     assert type(output['test-topic-document-matrix']) == np.ndarray
-    assert output['test-topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[2]))
+    assert output['test-topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_partitioned_corpus()[2]))
 
-def test_model_output_etm_with_text_word2vec_embeddings_file(data_dir, embeddings_dir):
+def test_model_output_etm_with_text_word2vec_embeddings_file(
+        data_dir, embeddings_dir):
     dataset = Dataset()
     dataset.load_custom_dataset_from_folder(data_dir + '/M10')
     num_topics = 3
-    model = ETM(num_topics=num_topics, num_epochs=5, train_embeddings=False, 
-        embeddings_type='word2vec', embeddings_path=embeddings_dir +'/test_example/example.txt', 
+    model = ETM(
+        num_topics=num_topics, num_epochs=5, train_embeddings=False,
+        embeddings_type='word2vec',
+        embeddings_path=embeddings_dir +'/test_example/example.txt',
         binary_embeddings=False)
     output = model.train_model(dataset)
     assert 'topics' in output.keys()
@@ -214,22 +241,29 @@ def test_model_output_etm_with_text_word2vec_embeddings_file(data_dir, embedding
 
     # check topic-word-matrix format
     assert type(output['topic-word-matrix']) == np.ndarray
-    assert output['topic-word-matrix'].shape == (num_topics, len(dataset.get_vocabulary()))
+    assert output['topic-word-matrix'].shape == (
+        num_topics, len(dataset.get_vocabulary()))
 
     # check topic-document-matrix format
     assert type(output['topic-document-matrix']) == np.ndarray
-    assert output['topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[0]))
+    assert output['topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_partitioned_corpus()[0]))
 
     # check test-topic-document-matrix format
     assert type(output['test-topic-document-matrix']) == np.ndarray
-    assert output['test-topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[2]))
+    assert output['test-topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_partitioned_corpus()[2]))
 
-def test_model_output_etm_with_headerless_text_word2vec_embeddings_file(data_dir, embeddings_dir):
+
+def test_model_output_etm_with_headerless_text_word2vec_embeddings_file(
+        data_dir, embeddings_dir):
     dataset = Dataset()
     dataset.load_custom_dataset_from_folder(data_dir + '/M10')
     num_topics = 3
-    model = ETM(num_topics=num_topics, num_epochs=5, train_embeddings=False, 
-        embeddings_type='word2vec', embeddings_path=embeddings_dir +'/test_example/headerless_example.txt', 
+    model = ETM(
+        num_topics=num_topics, num_epochs=5, train_embeddings=False,
+        embeddings_type='word2vec',
+        embeddings_path=embeddings_dir + '/test_example/headerless_example.txt',
         binary_embeddings=False, headerless_embeddings=True)
     output = model.train_model(dataset)
     assert 'topics' in output.keys()
@@ -242,22 +276,29 @@ def test_model_output_etm_with_headerless_text_word2vec_embeddings_file(data_dir
 
     # check topic-word-matrix format
     assert type(output['topic-word-matrix']) == np.ndarray
-    assert output['topic-word-matrix'].shape == (num_topics, len(dataset.get_vocabulary()))
+    assert output['topic-word-matrix'].shape == (
+        num_topics, len(dataset.get_vocabulary()))
 
     # check topic-document-matrix format
     assert type(output['topic-document-matrix']) == np.ndarray
-    assert output['topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[0]))
+    assert output['topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_partitioned_corpus()[0]))
 
     # check test-topic-document-matrix format
     assert type(output['test-topic-document-matrix']) == np.ndarray
-    assert output['test-topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[2]))
+    assert output['test-topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_partitioned_corpus()[2]))
 
-def test_model_output_etm_with_keyedvectors_embeddings_file(data_dir, embeddings_dir):
+
+def test_model_output_etm_with_keyedvectors_embeddings_file(
+        data_dir, embeddings_dir):
     dataset = Dataset()
     dataset.load_custom_dataset_from_folder(data_dir + '/M10')
     num_topics = 3
-    model = ETM(num_topics=num_topics, num_epochs=5, train_embeddings=False, 
-        embeddings_type='keyedvectors', embeddings_path=embeddings_dir +'/test_example/example.keyedvectors')
+    model = ETM(
+        num_topics=num_topics, num_epochs=5, train_embeddings=False,
+        embeddings_type='keyedvectors',
+        embeddings_path=embeddings_dir +'/test_example/example.keyedvectors')
     output = model.train_model(dataset)
     assert 'topics' in output.keys()
     assert 'topic-word-matrix' in output.keys()
@@ -269,15 +310,19 @@ def test_model_output_etm_with_keyedvectors_embeddings_file(data_dir, embeddings
 
     # check topic-word-matrix format
     assert type(output['topic-word-matrix']) == np.ndarray
-    assert output['topic-word-matrix'].shape == (num_topics, len(dataset.get_vocabulary()))
+    assert output['topic-word-matrix'].shape == (
+        num_topics, len(dataset.get_vocabulary()))
 
     # check topic-document-matrix format
     assert type(output['topic-document-matrix']) == np.ndarray
-    assert output['topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[0]))
+    assert output['topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_partitioned_corpus()[0]))
 
     # check test-topic-document-matrix format
     assert type(output['test-topic-document-matrix']) == np.ndarray
-    assert output['test-topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[2]))
+    assert output['test-topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_partitioned_corpus()[2]))
+
 
 def test_model_output_lda_tomotopy(data_dir):
     dataset = Dataset()
@@ -295,22 +340,27 @@ def test_model_output_lda_tomotopy(data_dir):
 
     # check topic-word-matrix format
     assert type(output['topic-word-matrix']) == np.ndarray
-    assert output['topic-word-matrix'].shape == (num_topics, len(dataset.get_vocabulary()))
+    assert output['topic-word-matrix'].shape == (
+        num_topics, len(dataset.get_vocabulary()))
 
     # check topic-document-matrix format
     assert type(output['topic-document-matrix']) == np.ndarray
-    assert output['topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[0]))
+    assert output['topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_partitioned_corpus()[0]))
 
     # check test-topic-document-matrix format
     assert type(output['test-topic-document-matrix']) == np.ndarray
-    assert output['test-topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[2]))
+    assert output['test-topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_partitioned_corpus()[2]))
 
 
 def test_model_output_nmf(data_dir):
     dataset = Dataset()
     dataset.load_custom_dataset_from_folder(data_dir + '/M10')
     num_topics = 3
-    model = NMF(num_topics=num_topics, w_max_iter=10, h_max_iter=10, use_partitions=True)
+    model = NMF(
+        num_topics=num_topics, w_max_iter=10, h_max_iter=10,
+        use_partitions=True)
     output = model.train_model(dataset)
     assert 'topics' in output.keys()
     assert 'topic-word-matrix' in output.keys()
@@ -322,15 +372,18 @@ def test_model_output_nmf(data_dir):
 
     # check topic-word-matrix format
     assert type(output['topic-word-matrix']) == np.ndarray
-    assert output['topic-word-matrix'].shape == (num_topics, len(dataset.get_vocabulary()))
+    assert output['topic-word-matrix'].shape == (
+        num_topics, len(dataset.get_vocabulary()))
 
     # check topic-document-matrix format
     assert type(output['topic-document-matrix']) == np.ndarray
-    assert output['topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[0]))
+    assert output['topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_partitioned_corpus()[0]))
 
     # check test-topic-document-matrix format
     assert type(output['test-topic-document-matrix']) == np.ndarray
-    assert output['test-topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[2]))
+    assert output['test-topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_partitioned_corpus()[2]))
 
 
 def test_model_output_nmf_scikit(data_dir):
@@ -349,15 +402,36 @@ def test_model_output_nmf_scikit(data_dir):
 
     # check topic-word-matrix format
     assert type(output['topic-word-matrix']) == np.ndarray
-    assert output['topic-word-matrix'].shape == (num_topics, len(dataset.get_vocabulary()))
+    assert output['topic-word-matrix'].shape == (
+        num_topics, len(dataset.get_vocabulary()))
 
     # check topic-document-matrix format
     assert type(output['topic-document-matrix']) == np.ndarray
-    assert output['topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[0]))
+    assert output['topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_partitioned_corpus()[0]))
 
     # check test-topic-document-matrix format
     assert type(output['test-topic-document-matrix']) == np.ndarray
-    assert output['test-topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[2]))
+    assert output['test-topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_partitioned_corpus()[2]))
+
+
+@pytest.mark.skip(reason='the test fails on github actions')
+def test_model_output_ctm_zeroshot_seeded(data_dir):
+    dataset = Dataset()
+    dataset.load_custom_dataset_from_folder(data_dir + '/M10')
+    num_topics = 3
+    model = CTM(
+        num_topics=num_topics, seed=10,
+        num_epochs=5, inference_type='zeroshot')
+    output = model.train_model(dataset)
+
+    model_2 = CTM(
+        num_topics=num_topics, seed=10,
+        num_epochs=5, inference_type='zeroshot')
+    output_2 = model_2.train_model(dataset)
+
+    assert output['topics'] == output_2['topics']
 
 
 def test_model_output_ctm_zeroshot(data_dir):
@@ -376,15 +450,18 @@ def test_model_output_ctm_zeroshot(data_dir):
 
     # check topic-word-matrix format
     assert type(output['topic-word-matrix']) == np.ndarray
-    assert output['topic-word-matrix'].shape == (num_topics, len(dataset.get_vocabulary()))
+    assert output['topic-word-matrix'].shape == (
+        num_topics, len(dataset.get_vocabulary()))
 
     # check topic-document-matrix format
     assert type(output['topic-document-matrix']) == np.ndarray
-    assert output['topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[0]))
+    assert output['topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_partitioned_corpus()[0]))
 
     # check test-topic-document-matrix format
     assert type(output['test-topic-document-matrix']) == np.ndarray
-    assert output['test-topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[2]))
+    assert output['test-topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_partitioned_corpus()[2]))
 
 
 def test_model_output_ctm_combined(data_dir):
@@ -403,23 +480,27 @@ def test_model_output_ctm_combined(data_dir):
 
     # check topic-word-matrix format
     assert type(output['topic-word-matrix']) == np.ndarray
-    assert output['topic-word-matrix'].shape == (num_topics, len(dataset.get_vocabulary()))
+    assert output['topic-word-matrix'].shape == (num_topics, len(
+        dataset.get_vocabulary()))
 
     # check topic-document-matrix format
     assert type(output['topic-document-matrix']) == np.ndarray
-    assert output['topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[0]))
+    assert output['topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_partitioned_corpus()[0]))
 
     # check test-topic-document-matrix format
     assert type(output['test-topic-document-matrix']) == np.ndarray
-    assert output['test-topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[2]))
+    assert output['test-topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_partitioned_corpus()[2]))
 
 
 def test_model_output_ctm_combined_not_partition(data_dir):
     dataset = Dataset()
     dataset.load_custom_dataset_from_folder(data_dir + '/M10')
     num_topics = 3
-    model = CTM(num_topics=num_topics, num_epochs=5, inference_type='combined',use_partitions=False,
-                bert_path='./not_part')
+    model = CTM(
+        num_topics=num_topics, num_epochs=5, inference_type='combined',
+        use_partitions=False, bert_path='./not_part')
     output = model.train_model(dataset)
     assert 'topics' in output.keys()
     assert 'topic-word-matrix' in output.keys()
@@ -431,11 +512,13 @@ def test_model_output_ctm_combined_not_partition(data_dir):
 
     # check topic-word-matrix format
     assert type(output['topic-word-matrix']) == np.ndarray
-    assert output['topic-word-matrix'].shape == (num_topics, len(dataset.get_vocabulary()))
+    assert output['topic-word-matrix'].shape == (
+        num_topics, len(dataset.get_vocabulary()))
 
     # check topic-document-matrix format
     assert type(output['topic-document-matrix']) == np.ndarray
-    assert output['topic-document-matrix'].shape == (num_topics, len(dataset.get_corpus()))
+    assert output['topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_corpus()))
 
 
 def test_model_output_prodlda(data_dir):
@@ -454,15 +537,18 @@ def test_model_output_prodlda(data_dir):
 
     # check topic-word-matrix format
     assert type(output['topic-word-matrix']) == np.ndarray
-    assert output['topic-word-matrix'].shape == (num_topics, len(dataset.get_vocabulary()))
+    assert output['topic-word-matrix'].shape == (
+        num_topics, len(dataset.get_vocabulary()))
 
     # check topic-document-matrix format
     assert type(output['topic-document-matrix']) == np.ndarray
-    assert output['topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[0]))
+    assert output['topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_partitioned_corpus()[0]))
 
     # check test-topic-document-matrix format
     assert type(output['test-topic-document-matrix']) == np.ndarray
-    assert output['test-topic-document-matrix'].shape == (num_topics, len(dataset.get_partitioned_corpus()[2]))
+    assert output['test-topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_partitioned_corpus()[2]))
 
 
 def test_model_output_prodlda_not_partitioned(data_dir):
@@ -481,9 +567,10 @@ def test_model_output_prodlda_not_partitioned(data_dir):
 
     # check topic-word-matrix format
     assert type(output['topic-word-matrix']) == np.ndarray
-    assert output['topic-word-matrix'].shape == (num_topics, len(dataset.get_vocabulary()))
+    assert output['topic-word-matrix'].shape == (
+        num_topics, len(dataset.get_vocabulary()))
 
     # check topic-document-matrix format
     assert type(output['topic-document-matrix']) == np.ndarray
-    assert output['topic-document-matrix'].shape == (num_topics, len(dataset.get_corpus()))
-
+    assert output['topic-document-matrix'].shape == (
+        num_topics, len(dataset.get_corpus()))
